@@ -53,6 +53,13 @@ def create_file_menu(main_window):
     
     file_menu.addSeparator()
     
+    # Load data action (databases, CSV, Excel, Parquet, etc.)
+    load_data_action = file_menu.addAction('Load Data...')
+    load_data_action.setShortcut('Ctrl+L')
+    load_data_action.triggered.connect(main_window.show_load_dialog)
+    
+    file_menu.addSeparator()
+    
     exit_action = file_menu.addAction('Exit')
     exit_action.setShortcut('Ctrl+Q')
     exit_action.triggered.connect(main_window.close)
@@ -79,6 +86,22 @@ def create_view_menu(main_window):
     
     view_menu.addSeparator()
     
+    # Toggle sidebar visibility
+    main_window.toggle_sidebar_action = view_menu.addAction('Toggle Sidebar')
+    main_window.toggle_sidebar_action.setShortcut('Ctrl+B')
+    main_window.toggle_sidebar_action.setCheckable(True)
+    main_window.toggle_sidebar_action.setChecked(True)  # Sidebar visible by default
+    main_window.toggle_sidebar_action.triggered.connect(main_window.toggle_sidebar)
+    
+    # Compact mode - reduces padding and hides secondary UI elements
+    main_window.compact_mode_action = view_menu.addAction('Compact Mode')
+    main_window.compact_mode_action.setShortcut('Ctrl+Shift+C')
+    main_window.compact_mode_action.setCheckable(True)
+    main_window.compact_mode_action.setChecked(False)
+    main_window.compact_mode_action.triggered.connect(main_window.toggle_compact_mode)
+    
+    view_menu.addSeparator()
+    
     # Maximized window option
     maximize_action = view_menu.addAction('Maximize Window')
     maximize_action.setShortcut('F11')
@@ -151,9 +174,25 @@ def create_preferences_menu(main_window):
     auto_load_action.setChecked(main_window.auto_load_recent_project)
     auto_load_action.triggered.connect(lambda checked: toggle_auto_load(main_window, checked))
     
+    preferences_menu.addSeparator()
+    
+    # AI Autocomplete settings
+    ai_settings_action = preferences_menu.addAction('🤖 AI Autocomplete Settings...')
+    ai_settings_action.triggered.connect(lambda: show_ai_settings(main_window))
+    
     return preferences_menu
 
 
+def show_ai_settings(main_window):
+    """Show the AI autocomplete settings dialog.
+    
+    Args:
+        main_window: The SQLShell main window instance
+    """
+    from sqlshell.ai_settings_dialog import show_ai_settings_dialog
+    show_ai_settings_dialog(main_window)
+
+
 def toggle_auto_load(main_window, checked):
     """Toggle the auto-load recent project setting.
     
